/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2008. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
dojo.provide("com.ibm.team.dashboard.web.ui.ViewletSite");

dojo.require("com.ibm.team.dashboard.web.ui.DashboardConstants");

(function(){

var DashboardConstants = com.ibm.team.dashboard.web.ui.DashboardConstants;

dojo.declare("com.ibm.team.dashboard.web.ui.ViewletSite",
	null, {
	
	constructor: function(args) {
		this._container = args.container;
		this._viewletHelper = args.viewletHelper;
		this._loading = false;
	},

	/*
	 * Adds a menu item to the viewlet menu.
	 * 
	 * @param label the text shown for the menu item.
	 * @param iconClass (optional) a css class name specifying a background-image property
	 * 		for the menu item's icon, or null for none.
	 * @param callback the function to call when the user activates the menu item. The scope
	 * 		(i.e. 'this') will be the viewlet adding the menu item.
	 */
	addMenuItem: function(/* string */ label, /* string */ iconClass, /* function */ callback) {
		this._container.addMenuItem(label, iconClass, dojo.hitch(this._container._viewlet, callback));
	},
	
	/*
	 * Returns true or false based on if the current server license level allows viewing of the
	 * indicated dashboard type.
	 * 
	 * @param scope a number representing one of the constants for the scope of the dashboard
	 * @param isPublic only applicable for contributor scope, if true, indicates that we are talking
	 * 		about a profile (not private) dashboard
	 */
	/* boolean */ canViewDashboard: function(/* number */ scope, /* booealn */ isPublic) {
		if (scope == DashboardConstants.SCOPE_PROJECT_AREA)
			return this._viewletHelper.getDashboardItem()._permissions.viewProject;
		if (scope == DashboardConstants.SCOPE_TEAM_AREA)
			return this._viewletHelper.getDashboardItem()._permissions.viewTeam;
		if (scope == DashboardConstants.SCOPE_CONTRIBUTOR) {
			if (isPublic)
				return this._viewletHelper.getDashboardItem()._permissions.viewProfile;
			return this._viewletHelper.getDashboardItem()._permissions.viewPersonal;
		}
		return false;
	},

	/*
	 * Enables or disables automatic periodic refreshing of viewlets. Viewlets
	 * may wish to temporarily disable automatic refresh if it disrupts the
	 * normal user flow when, for example, the user is reading a hover tooltip or
	 * editing content. Normal auto-refresh will resume as soon as it is re-enabled.
	 */
	setAutoRefresh: function(/* boolean */ value) {
		this._container.setAutoRefresh(value);
	},
	
	/*
	 * Sets the viewlet icon to the image pointed to by the given URL.
	 * 
	 * @param url the URL of the image file.
	 */
	setIcon: function(/* string */ url) {
		this._container._headerIcon.firstChild.src = url;
	},
	
	/*
	 * Called to set loading state of viewlet.  Displays progress icon when loading.
	 */
	setLoading: function(loadingStatus) {
		if (this._container._headerIcon.firstChild) {
			if (loadingStatus) {
				this._container._headerIcon.firstChild.style.display = "none";
				dojo.addClass(this._container._headerIcon, "progressIcon");
			}
			else {
				this._container._headerIcon.firstChild.style.display = "inline";
				dojo.removeClass(this._container._headerIcon, "progressIcon");
			}
		}
		this._loading = loadingStatus;
	},
	
	/*
 	 * Public Method
 	 * 
 	 * Indicates whether the viewlet is loading or not
 	 *  
 	 * @param void
 	 * @return boolean true = loading; false = not loading
 	 */	
	isLoading: function() {
		return this._loading;
	},	
	
	/*
	 * Can be called by viewlets to programatically open or close the settings area.
	 */
	toggleSettings: function() {
		this._container.toggleSettings();
	},
	
	/*
	 * Can be called by viewlets to programatically enter edit mode.
	 */
	editContents: function() {
		this._container.startEditing();
	},
	
	/*
	 * Called by viewlets to update the dynamic title. Some viewlets only know the title
	 * when the SettingsArea is closed. These viewlets should indicate that the title
	 * needs to be persisted by setting the persist flag to true. Note that this results
	 * in a dashboard modification and will make the Dashboard dirty, thus it should
	 * only be done in tandem with another action that dirties the dashboard, such as
	 * changing the viewlet settings.
	 */
	setTitle: function(/* string */ title, /* boolean */ persist) {
		// ignore the call if the user has overriden the title
		if (!this._viewletHelper.isUserTitle()) {
			if (persist)
				this._viewletHelper.setTitle(title);
			else 
				this._viewletHelper._title = title;
			// update the title on the container
			this._container.setTitle(title);
		}
	},
	
	setSecondaryTitle: function(/* string */ title) {
		this._container.setSecondaryTitle(title);
	},
	
	getTitle: function() {
		return this._viewletHelper.getTitle();
	},
	
	getSecondaryTitle: function() {
		return this._container.getSecondaryTitle();
	},
	
	getActionArea: function() {
		return this._container.actionArea;
	},
	
	isDashboardEditing: function() {
		return this._container.isEditing;
	},
	
	isActive: function() {
		var viewletPage = this._container.viewletPage;
		return viewletPage.dashboardContainer.isPageActive(viewletPage._viewletPageHelper.getId());
	},
	
	/*
 	 * Public Method
 	 * 
 	 * Returns the height of the viewlet's content area
 	 * 
 	 * @param void
 	 * @return Number
 	 */		
	getHeight: function() {
		if (dojo.isIE == 6)
			//directly sniff height for IE6 (dojo.style doesn't support IE6 properly)
			return this._container._contentWrapper.clientHeight;
		else
			return dojo.style(this._container._contentWrapper, "height");
	},
	
	/*
 	 * Public Method
 	 * 
 	 * Returns the width of the viewlet's content area
 	 * 
 	 * @param void
 	 * @return Number
 	 */		
	getWidth: function() {
		if (dojo.isIE == 6) {
			//look at header width instead (because IE6 gives wrong width if content is busting out the side)
			var width = this._container._header.clientWidth - 5; 
			
			//for trimless viewlet case
			if (width < 0) width = this._container._contentWrapper.clientWidth - 40;
			
			return width;
		} else
			return dojo.style(this._container._contentWrapper, "width");
	},
	
	doneRefresh: function() {
		this._container.isRefreshing--;
		if (this._container.isRefreshing < 0)
			this._container.isRefreshing = 0;
	},
	
	refresh: function() {
		this._container.refreshViewlet(true);
	},
	
	navigateAwayEvent: function(eventObj, workbenchNavigation) {
		return this._container.viewletPage.dashboardContainer.dashboardPage.navigateAwayEvent(eventObj, workbenchNavigation);
	}
});
	
})();
